@@ -4,7 +4,7 @@ use Imager::Color;
 use strict;
 use vars qw($VERSION);
 
-$VERSION = "1.035";
+$VERSION = "1.038";
 
 # the aim here is that we can:
 #  - add file based types in one place: here
@@ -249,7 +249,8 @@ sub bounding_box {
   $input{sizew} = _first($input{sizew}, $self->{sizew}, 0);
   $input{utf8} = _first($input{utf8}, $self->{utf8}, 0);
 
-  my @box = $self->_bounding_box(%input);
+  my @box = $self->_bounding_box(%input)
+    or return;
 
   if (wantarray) {
     if(@box && exists $input{'x'} and exists $input{'y'}) {
@@ -259,7 +260,7 @@ sub bounding_box {
       $box[0]+=$input{'x'};
       $box[2]+=$input{'x'};
     } elsif (@box && $input{'canon'}) {
-      $box[3]-=$box[1];    # make it cannoical (ie (0,0) - (width, height))
+      $box[3]-=$box[1];    # make it canonical (ie (0,0) - (width, height))
       $box[2]-=$box[0];
     }
     return @box;
@@ -544,6 +545,9 @@ the FreeType 2.x driver by setting C<type> to C<'ft2'>:
 
 =back
 
+Returns the new font object on success. Returns C<undef> on failure
+and sets an error message readable with C<< Imager->errstr >>.
+
 =item bounding_box()
 
 Returns the bounding box for the specified string.  Example:
@@ -666,6 +670,14 @@ and height of the text instead.
 
 =back
 
+On success returns either the list of bounds, or a bounding box object
+in scalar context.  Returns an empty list or C<undef> on failure and
+sets an error message readable with C<< Imager->errstr >>.
+
+The transformation matrix set by L</transform()> has no effect on the
+result of this method - the bounds of the untransformed text is
+returned.
+
 =item string()
 
 The $img->string(...) method is now documented in
@@ -747,7 +759,10 @@ still calculate the bounding box.
 
 =back
 
-Returns a list specifying the bounds of the drawn text.
+Returns a list specifying the bounds of the drawn text on success.
+Returns an empty list on failure, if an C<image> parameter was
+supplied the error message can be read with C<< $image->errstr >>,
+otherwise it's available as C<< Imager->errstr >>.
 
 =item dpi()
 
@@ -775,7 +790,9 @@ C<dpi> - set both horizontal and vertical resolution to this value.
 
 =back
 
-Returns a list containing the previous C<xdpi>, C<ydpi> values.
+Returns a list containing the previous C<xdpi>, C<ydpi> values on
+success.  Returns an empty list on failure, with an error message
+returned in C<< Imager->errstr >>.
 
 =item transform()
 
@@ -802,6 +819,11 @@ Note that the transformation is done in font co-ordinates where y
 increases as you move up, not image co-ordinates where y decreases as
 you move up.
 
+C<transform()> has no effect on the results of L</bounding_box()>.
+
+Returns true on success.  Returns false on failure with the cause
+readable from C<< Imager->errstr >>.
+
 =item has_chars(string=>$text)
 
 Checks if the characters in $text are defined by the font.
@@ -814,6 +836,9 @@ characters.  Supports UTF-8 where the font driver supports UTF-8.
 Not all fonts support this method (use $font->can("has_chars") to
 check.)
 
+On error, returns an empty list or undef in scalar context, and sets
+an error message readable with C<< Imager->errstr >>.
+
 =over
 
 =item *
@@ -834,7 +859,8 @@ the C<utf8> value passed to Imager::Font->new(...) or 0.
 =item face_name()
 
 Returns the internal name of the face.  Not all font types support
-this method yet.
+this method yet, so you should check with C<< $font->can("face_name")
+>> before calling C<face_name>.
 
 =item glyph_names(string=>$string [, utf8=>$utf8 ][, reliable_only=>0 ] );
 
@@ -856,6 +882,19 @@ say how those name tables are unreliable, or how FT2 handles them.
 Both FreeType 1.x and 2.x allow support for glyph names to not be
 included.
 
+If the supplied C<string> is marked as UTF-8 or the C<utf8> parameter
+is true and the supplied string does not contain valid UTF-8, returns
+an empty string and set an error message readable from C<<
+Imager->errstr >>,
+
+=item can_glyph_names()
+
+As a class method, returns true if the underlying library supports
+returning glyph names.
+
+As an object method, returns true if the supplied font supports
+returning glyph names.
+
 =item draw
 
 This is used by Imager's string() method to implement drawing text.
@@ -957,7 +996,7 @@ For example:
 
  $x = pack("C*", 0xE2, 0x80, 0x90); # character code 0x2010 HYPHEN
 
-You need to be be careful with versions of perl that have UTF-8
+You need to be careful with versions of perl that have UTF-8
 support, since your string may end up doubly UTF-8 encoded.
 
 For example:
@@ -967,7 +1006,7 @@ For example:
  # at this point $x is has the UTF-8 flag set, but has 5 characters,
  # none, of which is the constructed UTF-8 character
 
-The test script t/t38ft2font.t has a small example of this after the 
+The test script t/t38ft2font.t has a small example of this after the
 comment:
 
   # an attempt using emulation of UTF-8
